Package: ggseg3d
Title: Interactive 3D Brain Atlas Visualization
Version: 2.1.1
Authors@R: c(
    person("Athanasia Mo", "Mowinckel", , "a.m.mowinckel@psykologi.uio.no", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-5756-0223")),
    person("Didac", "Vidal-Piñeiro", , "d.v.pineiro@psykologi.uio.no", role = "aut",
           comment = c(ORCID = "0000-0001-9997-9156")),
    person("Center for Lifespan Changes in Brain and Cognition (LCBC), University of Oslo",
           role = "cph"),
    person("three.js authors", role = c("ctb", "cph"),
           comment = "Three.js and OrbitControls libraries, see LICENSE.note")
  )
Description: Plot brain atlases as interactive 3D meshes using 'Three.js'
    via 'htmlwidgets', or render publication-quality static images through
    'rgl' and 'rayshader'. A pipe-friendly API lets you map data onto
    brain regions, control camera angles, toggle region edges, overlay
    glass brains, and snapshot or ray-trace the result. Additional
    atlases are available through the 'ggsegverse' r-universe. Mowinckel
    & Vidal-Piñeiro (2020) <doi:10.1177/2515245920928009>.
License: MIT + file LICENSE
URL: https://github.com/ggsegverse/ggseg3d,
        https://ggsegverse.github.io/ggseg3d/
BugReports: https://github.com/ggsegverse/ggseg3d/issues
Depends: R (>= 4.1)
Imports: cli, dplyr, ggseg.formats, htmlwidgets, knitr, lifecycle,
        rlang, scales, tidyr, webshot2
Suggests: ggseg.meshes, png, rayshader, rgl, rmarkdown, shiny,
        spelling, testthat (>= 3.0.0)
VignetteBuilder: knitr
Config/Needs/website: ggsegverse/ggseg.docs
Config/testthat/edition: 3
Config/testthat/parallel: true
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-22 10:20:29 UTC; athanasm
Author: Athanasia Mo Mowinckel [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-5756-0223>),
  Didac Vidal-Piñeiro [aut] (ORCID:
    <https://orcid.org/0000-0001-9997-9156>),
  Center for Lifespan Changes in Brain and Cognition (LCBC), University
    of Oslo [cph],
  three.js authors [ctb, cph] (Three.js and OrbitControls libraries, see
    LICENSE.note)
Maintainer: Athanasia Mo Mowinckel <a.m.mowinckel@psykologi.uio.no>
Repository: CRAN
Date/Publication: 2026-04-22 11:00:02 UTC
Built: R 4.6.0; ; 2026-04-30 11:53:47 UTC; unix
