# Generated by roxygen2: do not edit by hand

S3method(knit_print,ggsegray)
S3method(prepare_brain_meshes,cerebellar_atlas)
S3method(prepare_brain_meshes,cortical_atlas)
S3method(prepare_brain_meshes,default)
S3method(prepare_brain_meshes,subcortical_atlas)
S3method(prepare_brain_meshes,tract_atlas)
S3method(print,ggsegray)
export(add_glassbrain)
export(aseg)
export(dk)
export(ggseg3d)
export(ggseg3dOutput)
export(ggsegray)
export(pan_camera)
export(renderGgseg3d)
export(resolve_brain_mesh)
export(set_background)
export(set_dimensions)
export(set_edges)
export(set_flat_shading)
export(set_legend)
export(set_orthographic)
export(set_positioning)
export(snapshot_brain)
export(tracula)
export(updateGgseg3dBackground)
export(updateGgseg3dCamera)
import(ggseg.formats)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,full_join)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(ggseg.formats,aseg)
importFrom(ggseg.formats,dk)
importFrom(ggseg.formats,tracula)
importFrom(graphics,par)
importFrom(graphics,plot.new)
importFrom(graphics,plot.window)
importFrom(graphics,rect)
importFrom(graphics,text)
importFrom(htmlwidgets,createWidget)
importFrom(htmlwidgets,shinyRenderWidget)
importFrom(htmlwidgets,shinyWidgetOutput)
importFrom(htmlwidgets,sizingPolicy)
importFrom(knitr,knit_print)
importFrom(lifecycle,deprecate_warn)
importFrom(lifecycle,deprecated)
importFrom(rlang,"%||%")
importFrom(rlang,.data)
importFrom(scales,brewer_pal)
importFrom(scales,colour_ramp)
importFrom(scales,gradient_n_pal)
importFrom(scales,rescale)
importFrom(tidyr,unite)
importFrom(webshot2,webshot)
