% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/brain-mesh.R
\name{build_tract_meshes}
\alias{build_tract_meshes}
\title{Build mesh list for tract atlases}
\usage{
build_tract_meshes(
  atlas_data,
  na_colour,
  color_by = "colour",
  atlas_centerlines = NULL,
  text_by = NULL,
  label_by = "region"
)
}
\arguments{
\item{atlas_data}{Prepared atlas data frame with label, colour, and mesh
columns}

\item{na_colour}{Colour for NA values}

\item{color_by}{How to colour tracts: "colour" (use colour column),
"orientation" (direction-based RGB from tangents)}
}
\value{
List of mesh data structures
}
\description{
Creates mesh data structures for tract atlases with per-vertex colouring.
Supports palette colours (uniform per tract) or orientation-based RGB
colours computed from centerline tangent vectors.
}
\keyword{internal}
