% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/brain-mesh.R
\name{cross_product}
\alias{cross_product}
\title{Cross product of two 3D vectors}
\usage{
cross_product(a, b)
}
\description{
Cross product of two 3D vectors
}
\keyword{internal}
