% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/legend.R
\name{build_legend_data}
\alias{build_legend_data}
\title{Build legend data structure}
\usage{
build_legend_data(
  is_numeric,
  data_min,
  data_max,
  palette,
  pal_colours,
  colour_col,
  label_col,
  fill_col,
  data
)
}
\arguments{
\item{is_numeric}{Whether the colour variable is numeric}

\item{data_min}{Minimum data value (for continuous)}

\item{data_max}{Maximum data value (for continuous)}

\item{palette}{Original palette specification}

\item{pal_colours}{Processed palette colours}

\item{colour_col}{Name of the colour column}

\item{label_col}{Name of the label column}

\item{fill_col}{Name of the fill column}

\item{data}{Atlas data}
}
\value{
List with legend specification or NULL
}
\description{
Creates the appropriate legend data structure based on whether the
colour variable is numeric (continuous colorbar) or categorical
(discrete legend).
}
\keyword{internal}
