% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/atlas-types.R
\name{prepare_atlas_data}
\alias{prepare_atlas_data}
\title{Prepare atlas data}
\usage{
prepare_atlas_data(atlas, .data)
}
\arguments{
\item{atlas}{A ggseg_atlas object}

\item{.data}{Optional user data to merge}
}
\value{
Prepared data frame with hemi, region, label, colour, and vertices
}
\description{
Extracts and prepares data from a ggseg_atlas object for rendering.
Joins vertices with core region info and palette colours.
}
\keyword{internal}
