% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/legend.R
\name{build_continuous_legend}
\alias{build_continuous_legend}
\title{Build continuous legend}
\usage{
build_continuous_legend(palette, pal_colours, colour_col, data_min, data_max)
}
\arguments{
\item{palette}{Original palette specification}

\item{pal_colours}{Processed palette colours}

\item{colour_col}{Name of the colour column (used as title)}

\item{data_min}{Minimum data value}

\item{data_max}{Maximum data value}
}
\value{
List with continuous legend specification
}
\description{
Creates a continuous colorbar legend specification for numeric data.
}
\keyword{internal}
