% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/colour.R
\name{apply_colour_palette}
\alias{apply_colour_palette}
\title{Apply colour palette}
\usage{
apply_colour_palette(atlas_data, colour, palette, na_colour)
}
\arguments{
\item{atlas_data}{Atlas data frame with vertices column}

\item{colour}{Column name for colour values}

\item{palette}{Colour palette specification}

\item{na_colour}{Colour for NA values}
}
\value{
List with data, fill column name, palette, and colour metadata
}
\description{
Processes colour mapping for ggseg_atlas objects using
vertex-based colouring.
}
\keyword{internal}
