% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/brain-mesh.R
\name{tangents_to_colors}
\alias{tangents_to_colors}
\title{Convert tangent vectors to orientation RGB colours}
\usage{
tangents_to_colors(mesh_data)
}
\arguments{
\item{mesh_data}{Mesh data with vertices data.frame and metadata list}
}
\value{
Character vector of hex colours (one per mesh vertex)
}
\description{
Computes direction-based RGB colours from centerline tangent vectors.
Standard tractography colouring: R = left-right (x),
G = anterior-posterior (y), B = superior-inferior (z).
}
\keyword{internal}
